@@ -9,7 +9,10 @@ var searchData=
   ['noderef_6',['NodeRef',['../classosmium_1_1NodeRef.html',1,'osmium']]],
   ['nodereflist_7',['NodeRefList',['../classosmium_1_1NodeRefList.html',1,'osmium']]],
   ['nodereflistbuilder_8',['NodeRefListBuilder',['../classosmium_1_1builder_1_1NodeRefListBuilder.html',1,'osmium::builder']]],
-  ['nodes_5fhandler_9',['nodes_handler',['../structdetail_1_1nodes__handler.html',1,'detail']]],
-  ['not_5ffound_10',['not_found',['../structosmium_1_1not__found.html',1,'osmium']]],
-  ['nwr_5farray_11',['nwr_array',['../classosmium_1_1nwr__array.html',1,'osmium']]]
+  ['nodereflistbuilder_3c_20innerring_20_3e_9',['NodeRefListBuilder&lt; InnerRing &gt;',['../classosmium_1_1builder_1_1NodeRefListBuilder.html',1,'osmium::builder']]],
+  ['nodereflistbuilder_3c_20outerring_20_3e_10',['NodeRefListBuilder&lt; OuterRing &gt;',['../classosmium_1_1builder_1_1NodeRefListBuilder.html',1,'osmium::builder']]],
+  ['nodereflistbuilder_3c_20waynodelist_20_3e_11',['NodeRefListBuilder&lt; WayNodeList &gt;',['../classosmium_1_1builder_1_1NodeRefListBuilder.html',1,'osmium::builder']]],
+  ['nodes_5fhandler_12',['nodes_handler',['../structdetail_1_1nodes__handler.html',1,'detail']]],
+  ['not_5ffound_13',['not_found',['../structosmium_1_1not__found.html',1,'osmium']]],
+  ['nwr_5farray_14',['nwr_array',['../classosmium_1_1nwr__array.html',1,'osmium']]]
 ];
