@@ -3,5 +3,5 @@ var searchData=
   ['relationhandle_0',['RelationHandle',['../classosmium_1_1relations_1_1RelationsDatabase.html#a748142a0dc17a16e608996b27623789e',1,'osmium::relations::RelationsDatabase']]],
   ['relationsdatabase_1',['RelationsDatabase',['../classosmium_1_1relations_1_1RelationHandle.html#ad7bad18267df047f4f6dd3637f425cde',1,'osmium::relations::RelationHandle']]],
   ['relationsmapindexes_2',['RelationsMapIndexes',['../classosmium_1_1index_1_1RelationsMapIndex.html#a3196a302f0aa1e3a071fbe6b3d462c6e',1,'osmium::index::RelationsMapIndex']]],
-  ['relationsmapstash_3',['RelationsMapStash',['../classosmium_1_1index_1_1RelationsMapIndex.html#a6ef229fb15bfa50cfe9a37da5479ce12',1,'osmium::index::RelationsMapIndex::RelationsMapStash'],['../classosmium_1_1index_1_1RelationsMapIndexes.html#a6ef229fb15bfa50cfe9a37da5479ce12',1,'osmium::index::RelationsMapIndexes::RelationsMapStash']]]
+  ['relationsmapstash_3',['RelationsMapStash',['../classosmium_1_1index_1_1RelationsMapIndex.html#a6ef229fb15bfa50cfe9a37da5479ce12',1,'osmium::index::RelationsMapIndex::RelationsMapStash()'],['../classosmium_1_1index_1_1RelationsMapIndexes.html#a6ef229fb15bfa50cfe9a37da5479ce12',1,'osmium::index::RelationsMapIndexes::RelationsMapStash()']]]
 ];
